<?php

namespace Litecms\History\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\History\Models\DepositPlanHistory;

class DepositPlanHistoryPolicy
{

    /**
     * Determine if the given user can view the deposit_plan_history.
     *
     * @param UserPolicy $user
     * @param DepositPlanHistory $deposit_plan_history
     *
     * @return bool
     */
    public function view(UserPolicy $user, DepositPlanHistory $deposit_plan_history)
    {
        if ($user->canDo('history.deposit_plan_history.view') && $user->isAdmin()) {
            return true;
        }

        return $deposit_plan_history->user_id == user_id() && $deposit_plan_history->user_type == user_type();
    }

    /**
     * Determine if the given user can create a deposit_plan_history.
     *
     * @param UserPolicy $user
     * @param DepositPlanHistory $deposit_plan_history
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('history.deposit_plan_history.create');
    }

    /**
     * Determine if the given user can update the given deposit_plan_history.
     *
     * @param UserPolicy $user
     * @param DepositPlanHistory $deposit_plan_history
     *
     * @return bool
     */
    public function update(UserPolicy $user, DepositPlanHistory $deposit_plan_history)
    {
        if ($user->canDo('history.deposit_plan_history.edit') && $user->isAdmin()) {
            return true;
        }

        return $deposit_plan_history->user_id == user_id() && $deposit_plan_history->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given deposit_plan_history.
     *
     * @param UserPolicy $user
     * @param DepositPlanHistory $deposit_plan_history
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, DepositPlanHistory $deposit_plan_history)
    {
        return $deposit_plan_history->user_id == user_id() && $deposit_plan_history->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given deposit_plan_history.
     *
     * @param UserPolicy $user
     * @param DepositPlanHistory $deposit_plan_history
     *
     * @return bool
     */
    public function verify(UserPolicy $user, DepositPlanHistory $deposit_plan_history)
    {
        if ($user->canDo('history.deposit_plan_history.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given deposit_plan_history.
     *
     * @param UserPolicy $user
     * @param DepositPlanHistory $deposit_plan_history
     *
     * @return bool
     */
    public function approve(UserPolicy $user, DepositPlanHistory $deposit_plan_history)
    {
        if ($user->canDo('history.deposit_plan_history.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
